This is the mail archive of the cluster-cvs@sourceware.org mailing list for the cluster.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

cluster: STABLE2 - gfs-kernel: Bring gfs1 up to speed with 2.6.29-rc2


Gitweb:        http://git.fedorahosted.org/git/cluster.git?p=cluster.git;a=commitdiff;h=806fd4635ccd8bb9660a77a5ac75aba8a6d940fb
Commit:        806fd4635ccd8bb9660a77a5ac75aba8a6d940fb
Parent:        7ca847579d8fff742336cd6b86011ed25bdb93ea
Author:        Abhijith Das <adas@redhat.com>
AuthorDate:    Thu Jan 22 14:12:54 2009 -0600
Committer:     Abhijith Das <adas@redhat.com>
CommitterDate: Wed Apr 15 21:59:04 2009 -0500

gfs-kernel: Bring gfs1 up to speed with 2.6.29-rc2

This patch fixes gfs1 to compile and run with 2.6.29-rc2

Signed-off-by: Abhijith Das <adas@redhat.com>
---
 gfs-kernel/src/gfs/ops_address.c |    2 +-
 gfs-kernel/src/gfs/ops_super.c   |   20 +++++++++++---------
 2 files changed, 12 insertions(+), 10 deletions(-)

diff --git a/gfs-kernel/src/gfs/ops_address.c b/gfs-kernel/src/gfs/ops_address.c
index 55071a2..5e55477 100644
--- a/gfs-kernel/src/gfs/ops_address.c
+++ b/gfs-kernel/src/gfs/ops_address.c
@@ -331,7 +331,7 @@ gfs_write_begin(struct file *file, struct address_space *mapping,
 		return -ENOSYS;
 
 	error = -ENOMEM;
-	page = __grab_cache_page(mapping, index);
+	page = grab_cache_page_write_begin(mapping, index, flags);
 	*pagep = page;
 	if (!page)
 		goto out;
diff --git a/gfs-kernel/src/gfs/ops_super.c b/gfs-kernel/src/gfs/ops_super.c
index afac554..51134d2 100644
--- a/gfs-kernel/src/gfs/ops_super.c
+++ b/gfs-kernel/src/gfs/ops_super.c
@@ -183,19 +183,19 @@ gfs_write_super(struct super_block *sb)
 }
 
 /**
  * gfs_write_super_lockfs - prevent further writes to the filesystem
  * @sb: the VFS structure for the filesystem
  *
  */
 
-static void
-gfs_write_super_lockfs(struct super_block *sb)
+static int
+gfs_freeze(struct super_block *sb)
 {
 	struct gfs_sbd *sdp = get_v2sdp(sb);
 	int error;
 
 	if (test_bit(SDF_SHUTDOWN, &sdp->sd_flags))
-		return;
+		return -EINVAL;
 
 	atomic_inc(&sdp->sd_ops_super);
 
@@ -221,22 +221,24 @@ gfs_write_super_lockfs(struct super_block *sb)
 		set_current_state(TASK_UNINTERRUPTIBLE);
 		schedule_timeout(HZ);
 	}
+	return 0;
 }
 
 /**
  * gfs_unlockfs - reallow writes to the filesystem
  * @sb: the VFS structure for the filesystem
  *
  */
 
-static void
-gfs_unlockfs(struct super_block *sb)
+static int
+gfs_unfreeze(struct super_block *sb)
 {
 	struct gfs_sbd *sdp = get_v2sdp(sb);
 
 	atomic_inc(&sdp->sd_ops_super);
 
 	gfs_unfreeze_fs(sdp);
+	return 0;
 }
 
 /**
@@ -446,8 +448,8 @@ struct super_operations gfs_super_ops = {
 	.drop_inode = gfs_drop_inode,
 	.put_super = gfs_put_super,
 	.write_super = gfs_write_super,
-	.write_super_lockfs = gfs_write_super_lockfs,
-	.unlockfs = gfs_unlockfs,
+	.freeze_fs = gfs_freeze,
+	.unfreeze_fs = gfs_unfreeze,
 	.statfs = gfs_statfs,
 	.remount_fs = gfs_remount_fs,
 	.clear_inode = gfs_clear_inode,
@@ -183,19 +183,19 @@ gfs_write_super(struct super_block *sb)
 
 /**
- * gfs_write_super_lockfs - prevent further writes to the filesystem
+ * gfs_freeze - prevent further writes to the filesystem
  * @sb: the VFS structure for the filesystem
  *
@@ -221,22 +221,24 @@ gfs_write_super_lockfs(struct super_block *sb)
 
 /**
- * gfs_unlockfs - reallow writes to the filesystem
+ * gfs_unfreeze - reallow writes to the filesystem
  * @sb: the VFS structure for the filesystem
  *


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]